@@ -8,6 +8,8 @@ use FFI::CheckLib ();
 use FFI::Platypus 1.00;
 use FFI::C;
 
+our $VERSION = '0.002';
+
 my $ffi;
 BEGIN {
     $ffi = FFI::Platypus->new( api => 1 );
@@ -243,7 +245,7 @@ BEGIN {
         CHAR_POW2               => 253,
         CHAR_BULLET_SQUARE      => 254,
     },
-    FontFlags => {
+    FontFlag => {
         FONT_LAYOUT_ASCII_INCOL =>   1,
         FONT_LAYOUT_ASCII_INROW =>   2,
         FONT_TYPE_GREYSCALE     =>   4,
